# Step Miscellaneous

Miscellaneous Step commands are used for configuring controls, damping, and frequency tables.

## Classes

### CompositeDamping

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.CompositeDamping.CompositeDamping
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### CompositeDampingComponent

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.CompositeDampingComponent.CompositeDampingComponent
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### CompositeDampingComponentArray

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.CompositeDampingComponentArray.CompositeDampingComponentArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Control

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.Control.Control
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### DirectDamping

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.DirectDamping.DirectDamping
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### DirectDampingByFrequency

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.DirectDampingByFrequency.DirectDampingByFrequency
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### DirectDampingByFrequencyComponent

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.DirectDampingByFrequencyComponent.DirectDampingByFrequencyComponent
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### DirectDampingByFrequencyComponentArray

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.DirectDampingByFrequencyComponentArray.DirectDampingByFrequencyComponentArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### DirectDampingComponent

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.DirectDampingComponent.DirectDampingComponent
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### DirectDampingComponentArray

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.DirectDampingComponentArray.DirectDampingComponentArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### EmagTimeHarmonicFrequency

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.EmagTimeHarmonicFrequency.EmagTimeHarmonicFrequency
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### EmagTimeHarmonicFrequencyArray

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.EmagTimeHarmonicFrequencyArray.EmagTimeHarmonicFrequencyArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### MassScaling

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.MassScaling.MassScaling
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### MassScalingArray

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.MassScalingArray.MassScalingArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### RandomResponseFrequency

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.RandomResponseFrequency.RandomResponseFrequency
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### RandomResponseFrequencyArray

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.RandomResponseFrequencyArray.RandomResponseFrequencyArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### RayleighDamping

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.RayleighDamping.RayleighDamping
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### RayleighDampingByFrequency

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.RayleighDampingByFrequency.RayleighDampingByFrequency
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### RayleighDampingByFrequencyComponent

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.RayleighDampingByFrequencyComponent.RayleighDampingByFrequencyComponent
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### RayleighDampingByFrequencyComponentArray

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.RayleighDampingByFrequencyComponentArray.RayleighDampingByFrequencyComponentArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### RayleighDampingComponent

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.RayleighDampingComponent.RayleighDampingComponent
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### RayleighDampingComponentArray

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.RayleighDampingComponentArray.RayleighDampingComponentArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ResponseSpectrumComponent

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.ResponseSpectrumComponent.ResponseSpectrumComponent
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ResponseSpectrumComponentArray

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.ResponseSpectrumComponentArray.ResponseSpectrumComponentArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SolverControl

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.SolverControl.SolverControl
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SteadyStateDirectFrequency

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.SteadyStateDirectFrequency.SteadyStateDirectFrequency
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SteadyStateDirectFrequencyArray

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.SteadyStateDirectFrequencyArray.SteadyStateDirectFrequencyArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SteadyStateModalFrequency

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.SteadyStateModalFrequency.SteadyStateModalFrequency
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SteadyStateModalFrequencyArray

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.SteadyStateModalFrequencyArray.SteadyStateModalFrequencyArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SteadyStateSubspaceFrequency

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.SteadyStateSubspaceFrequency.SteadyStateSubspaceFrequency
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SteadyStateSubspaceFrequencyArray

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.SteadyStateSubspaceFrequencyArray.SteadyStateSubspaceFrequencyArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### StructuralDamping

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.StructuralDamping.StructuralDamping
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### StructuralDampingByFrequency

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.StructuralDampingByFrequency.StructuralDampingByFrequency
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### StructuralDampingByFrequencyComponent

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.StructuralDampingByFrequencyComponent.StructuralDampingByFrequencyComponent
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### StructuralDampingByFrequencyComponentArray

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.StructuralDampingByFrequencyComponentArray.StructuralDampingByFrequencyComponentArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### StructuralDampingComponent

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.StructuralDampingComponent.StructuralDampingComponent
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### StructuralDampingComponentArray

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.StructuralDampingComponentArray.StructuralDampingComponentArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SubstructureGenerateFrequency

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.SubstructureGenerateFrequency.SubstructureGenerateFrequency
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SubstructureGenerateFrequencyArray

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.SubstructureGenerateFrequencyArray.SubstructureGenerateFrequencyArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SubstructureGenerateModes

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.SubstructureGenerateModes.SubstructureGenerateModes
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SubstructureGenerateModesArray

```{eval-rst}
.. autoclass:: abaqus.StepMiscellaneous.SubstructureGenerateModesArray.SubstructureGenerateModesArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```
